PredictionV2Builder class
- Inheritance
-
- Object
- HubbleViewBuilder<
PredictionV2Builder> - PredictionV2Builder
Constructors
-
PredictionV2Builder({Key? key, required Future<
void> refreshV4ProfileImmediate()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
final
-
refreshV4ProfileImmediate
→ Future<
void> Function() -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
view(
BuildContext context) → Widget -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited